/**
 * Copyright (C) oStorybook Team
 *
 * This program is free software, see <http://www.gnu.org/licenses/>.
 *
 * Parts of this code are from the SHEF project developed and published by Bob Tantlinger.
 */
package shef.editors.wys;

import i18n.I18N;
import java.awt.event.ActionEvent;
import java.awt.event.InputEvent;
import java.awt.event.KeyEvent;
import javax.swing.JEditorPane;
import javax.swing.KeyStroke;
import resources.icons.IconUtil;

/**
 * Action which inserts special characters like cadratin
 *
 * @author Bob Tantlinger
 *
 */
public class HTMLCadratinAction extends HTMLTextEditAction {

	public static final int CADRATIN = 0,
			DLG_OPEN_EN = 1,
			DLG_CLOSE_EN = 2,
			DLG_OPEN_FR = 3,
			DLG_CLOSE_FR = 4,
			UNBREAK = 5;
	public static final String TYPES[][] = {
		{"char_cadratin", "—\u00A0"},
		{"dlg_open_en", "“\u00A0"},
		{"dlg_close_en", "\u00A0”"},
		{"dlg_open_fr", "«\u00A0"},
		{"dlg_close_fr", "\u00A0»"},
		{"char_unbreak", "\u00A0"}
	};
	private int type;

	public HTMLCadratinAction(WysiwygEditor editor, int c) {
		super(editor, TYPES[c][0]);
		setShortDescription(I18N.getMsg("shef." + TYPES[c][0]));
		setSmallIcon(IconUtil.getIconSmall(TYPES[c][0]));
		if (c == UNBREAK) {
			setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_SPACE,
					InputEvent.SHIFT_DOWN_MASK | InputEvent.CTRL_DOWN_MASK));
		}
		if (c == CADRATIN) {
			setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_MINUS,
					InputEvent.SHIFT_DOWN_MASK | InputEvent.CTRL_DOWN_MASK));
		}
		type = c;
	}

	@Override
	protected void wysiwygEditPerformed(ActionEvent e, JEditorPane editor) {
		try {
			int caret = editor.getCaretPosition();
			if (caret < 1) {
				return;
			}
			String c = TYPES[type][1];
			String x = editor.getSelectedText();
			if (x == null || x.isEmpty()) {
				editor.setSelectionStart(caret);
				editor.setSelectionEnd(caret);
			}
			editor.replaceSelection(c);
		} catch (Exception ex) {
			ex.printStackTrace(System.err);
		}
	}
}
