/*
Storybook: Open Source software for novelists and authors.
Copyright (C) 2008 - 2012 Martin Mustun

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package storybook.action;

import java.awt.event.ActionEvent;
import java.util.List;
import javax.swing.JOptionPane;
import org.hibernate.Session;
import storybook.ctrl.Ctrl;
import i18n.I18N;
import storybook.model.EntityUtil;
import storybook.model.Model;
import storybook.model.hbn.dao.PartDAOImpl;
import storybook.model.hbn.entity.AbstractEntity;
import storybook.model.hbn.entity.Part;
import resources.icons.ICONS;
import resources.icons.IconUtil;
import static storybook.toolkit.swing.SwingUtil.showModalDialog;
import storybook.ui.MainFrame;
import storybook.ui.dialog.ConfirmDeleteDlg;

/**
 * @author martin
 *
 */
public class DeleteEntityAction extends AbstractEntityAction {

	private boolean confirm = false;

	public DeleteEntityAction(MainFrame mainFrame, AbstractEntity entity) {
		super(mainFrame, entity, I18N.getMsg("delete"), IconUtil.getIconSmall(ICONS.K.DELETE));
		this.mainFrame = mainFrame;
		this.entity = entity;
	}

	@Override
	public void actionPerformed(ActionEvent e) {
		// check if read only
		List<Long> readOnlyIds = EntityUtil.getReadOnlyIds(entity);
		if (readOnlyIds.contains(entity.getId())) {
			JOptionPane.showMessageDialog(mainFrame,
					I18N.getMsg("no.delete"),
					I18N.getMsg("warning"),
					JOptionPane.ERROR_MESSAGE);
			return;
		}
		ConfirmDeleteDlg dlg = new ConfirmDeleteDlg(mainFrame, entity);
		showModalDialog(dlg, mainFrame, true);
		if (dlg.isCanceled()) {
			return;
		}
		confirm = true;
		Ctrl ctrl = mainFrame.getBookController();
		if (entity instanceof Part
				&& mainFrame.getLastPart().getId().equals(entity.getId())) {
			// current part will be delete, change to first part
			Model model = mainFrame.getBookModel();
			Session session = model.beginTransaction();
			PartDAOImpl dao = new PartDAOImpl(session);
			Part firstPart = dao.findFirst();
			session.close();
			mainFrame.setLastPart(firstPart);
		}
		ctrl.deleteEntity(entity);
	}

	public boolean isConfirm() {
		return confirm;
	}
}
