/*
Storybook: Open Source software for novelists and authors.
Copyright (C) 2008 - 2012 Martin Mustun

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package storybook.ui.panel.navigation;

import i18n.I18N;
import java.awt.event.ActionEvent;
import java.beans.PropertyChangeEvent;
import javax.swing.JTabbedPane;
import net.infonode.docking.View;
import org.miginfocom.swing.MigLayout;
import storybook.ctrl.Ctrl;
import storybook.ui.MainFrame;
import storybook.ui.panel.AbstractPanel;

/**
 * @author martin
 *
 */
@SuppressWarnings("serial")
public class NavigationPanel extends AbstractPanel {

	private JTabbedPane tabbedPane;

	public NavigationPanel(MainFrame mainFrame) {
		super(mainFrame);
	}

	@Override
	public void modelPropertyChange(PropertyChangeEvent evt) {
		//LOG.trace(this.getClass().getSimpleName()+".modelPropertyChange("+evt.toString()+")");
		Object newValue = evt.getNewValue();
		String propName = evt.getPropertyName();
		if (Ctrl.PROPS.REFRESH.check(propName)) {
			View newView = (View) newValue;
			View view = (View) getParent().getParent();
			if (view == newView) {
				refresh();
			}
			return;
		}
		if (propName.startsWith("Edit") || propName.startsWith("Init")) {
			return;
		}
		if (propName.contains("Scene") || propName.contains("Chapter") || propName.contains("Strand")) {
			refresh();
		}
	}

	@Override
	public void refresh() {
		//LOG.trace("NavigationPanel.refresh()");
		int index = tabbedPane.getSelectedIndex();
		super.refresh();
		tabbedPane.setSelectedIndex(index);
	}

	@Override
	public void init() {
		//LOG.trace(this.getClass().getSimpleName()+".init()");
	}

	@Override
	public void initUi() {
		//LOG.trace(this.getClass().getSimpleName()+".initUi()");
		setLayout(new MigLayout("wrap,fill,ins 0"));
		//no toolbar to set
		tabbedPane = new JTabbedPane();
		tabbedPane.addTab(I18N.getMsg("navigate.goto.chapter"), new FindChapterPanel(mainFrame));
		tabbedPane.addTab(I18N.getMsg("navigate.goto.date"), new FindDatePanel(mainFrame));
		add(tabbedPane, "grow");
	}

	@Override
	public void actionPerformed(ActionEvent e) {
		// empty
	}

}
